/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.commons.daemon;


/**
 * Defines methods needed by the DaemonLoader.
 */
public interface DaemonController
{

    /**
     * Shuts down the daemon.
     *
     * @throws IllegalStateException If the daemon is not in a valid state to be
     *                               shutdown
     */
    public void shutdown()
        throws IllegalStateException;

    /**
     * Reloads daemon
     *
     * @throws IllegalStateException If the daemon is not in a valid state to be
     *                               reloaded
     */
    public void reload()
        throws IllegalStateException;

    /**
     * Shuts down daemon and logs failed message.
     *
     * @throws IllegalStateException If the daemon is not in a valid state to be
     *                               shutdown
     */
    public void fail()
        throws IllegalStateException;

    /**
     * Shuts down daemon and logs failed message.
     *
     * @param   message The message to log
     *
     * @throws IllegalStateException If the daemon is not in a valid state to be
     *                               shutdown
     */
    public void fail(String message)
        throws IllegalStateException;

    /**
     * Shuts down daemon and logs failed message.
     *
     * @param   exception   The exception to log
     *
     * @throws IllegalStateException If the daemon is not in a valid state to be
     *                               shutdown
     */
    public void fail(Exception exception)
        throws IllegalStateException;

    /**
     * Shuts down daemon and logs failed message.
     *
     * @param   message     The message to log
     * @param   exception   The exception to log
     *
     * @throws IllegalStateException If the daemon is not in a valid state to be
     *                               shutdown
     */
    public void fail(String message, Exception exception)
        throws IllegalStateException;

}

